/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.test.docker.internal.junit5;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.concurrent.Executors;
import java.util.function.Consumer;

/**
 * Utility methods to execute system commands for debugging reasons.
 *
 * @version $Id: 1126f3d094bf918e57fa3d1d234e1ac174633a37 $
 */
public final class RuntimeUtils
{
    private RuntimeUtils()
    {
        // Prevents instantiation.
    }

    /**
     * @param command the command to execute (e.g. "docker ps -a")
     * @return the command result
     * @throws Exception if the command execution fails
     */
    public static String run(String command) throws Exception
    {
        StringBuilder output = new StringBuilder();
        output.append("Execution of '").append(command).append("':");
        ProcessBuilder builder = new ProcessBuilder();
        builder.command("sh", "-c", command);
        builder.directory(new File(System.getProperty("user.home")));
        Process process = builder.start();
        StreamGobbler streamGobbler = new StreamGobbler(process.getInputStream(), (it) -> {
            output.append('\n').append(it);
        });
        Executors.newSingleThreadExecutor().submit(streamGobbler);
        process.waitFor();
        return output.toString();
    }

    private static class StreamGobbler implements Runnable
    {
        private InputStream inputStream;
        private Consumer<String> consumer;

        StreamGobbler(InputStream inputStream, Consumer<String> consumer)
        {
            this.inputStream = inputStream;
            this.consumer = consumer;
        }

        @Override
        public void run()
        {
            new BufferedReader(new InputStreamReader(inputStream)).lines()
                .forEach(consumer);
        }
    }
}
